# coding: utf-8

import json
import os
from uuid import uuid4
import requests
from .log import log


class Tokenizer(object):
    def __init__(self):
        self.is_test = False

    def get_token(self, systemId, **args):
        """
        curl -X POST https://devpfront.a-3.ru/token/api/v1 \
            -H 'content-type: application/json' \
            -d '{
                "systemId": "EXAMPLE",
                "cardNumber": "5500000000000000",
                "cardCVV": "000",
                "cardExp": "1111",
                "cardHolder": "CARD OWNER",
                "orderId": "1"
            }'
        """
        data = {
            "systemId": systemId,
        }
        if args.get('cardNumber'):
            data["cardNumber"] = args.get('cardNumber')
        if args.get('cardCVV'):
            data["cardCVV"] = args.get('cardCVV')
        if args.get('cardExp'):
            data["cardExp"] = args.get('cardExp')
        if args.get('cardHolder'):
            data["cardHolder"] = args.get('cardHolder')
        if args.get('orderId'):
            data["orderId"] = args.get('orderId')
        if args.get('userId'):
            data["userId"] = args.get('userId')

        resource = 'https://pfront.a-3.ru/token/api/v1'
        if self.is_test:
            resource = 'https://devpfront.a-3.ru/token/api/v1'
        res = requests.post(resource, json=data)

        return res.json()



""""""

class InvalidPaymentType(Exception):
    pass


class InvalidPhoneNumber(Exception):
    pass


class InvalidAmountType(Exception):
    pass


class InvalidCurrencyType(Exception):
    pass


class MissingToken(Exception):
    pass



# coding: utf-8

from requests import Session
from zeep import Client
from zeep.transports import Transport


class PF(object):
    def __init__(self, cert_crt=None, cert_key=None, is_test=False):
        self.is_test = is_test
        self.cert_crt = cert_crt
        self.cert_key = cert_key

    def _client(self):
        session = Session()
        session.cert = (self.cert_crt, self.cert_key)
        transport = Transport(session=session)
        wsdl = 'https://pfront2.a-3.ru/ProcessingFront/ProcessingFrontWS?WSDL'
        if self.is_test:
            wsdl = 'https://devpfront2.a-3.ru/ProcessingFront/ProcessingFrontWS?WSDL'
        return Client(wsdl=wsdl, transport=transport)

    def client(self):
        return self._client()

    def WSDL(self):
        return self._client().wsdl

    def request(self, method, **args):
        # TODO: ...
        client = self._client()
        return client.create_message(client.service, method, **args)

    def initPayment(self, **args):
        """Method `initPayment`

        >>> .cancelPayment(systemID='EXAMPLE', orderID='560ce567-dd57-4d3b-a1b5-d358ce932810')
        """
        return self._client().service.initPayment(**args)

    def initAuthentication(self, **args):
        return self._client().service.initAuthentication(**args)

    def cancelPayment(self, **args):
        """Method `cancelPayment`

        >>> .cancelPayment(systemID='EXAMPLE', orderID='560ce567-dd57-4d3b-a1b5-d358ce932810')
        """
        return self._client().service.cancelPayment(**args)

    def enableRecurringKey(self, **args):
        """Method `enableRecurringKey`

        >>> .enableRecurringKey(systemID='EXAMPLE', key='1000000000', user={'phone': '9100000000'})
        {
            'code': 3,
            'description': 'Ключ не найден [key=1000000000].'
        }
        """
        return self._client().service.enableRecurringKey(**args)

    def getPaymentInfo(self, **args):
        """
        >>> .getPaymentInfo(**dict(systemID='EXAMPLE', orderID='38d2aefe-21ea-4e3b-91aa-05d9905f2d21'))
        {
            'operationResult': {
                'code': 1,
                'description': 'OK'
            },
            'orderID': '38d2aefe-21ea-4e3b-91aa-05d9905f2d21',
            'authCode': '111111',
            'terminal': '11111111',
            'cardNumber': '220000******0000',
            'bills': None,
            'trID': 1000000000
        }
        """
        return self._client().service.getPaymentInfo(**args)

    def getPaymentStatus(self, **args):
        """
        >>> .getPaymentStatus(**dict(systemID='EXAMPLE', orderID='38d2aefe-21ea-4e3b-91aa-05d9905f2d21'))
        {
            'operationResult': {
                'code': 1,
                'description': 'OK'
            },
            'orderStatus': {
                'orderID': '38d2aefe-21ea-4e3b-91aa-05d9905f2d21',
                'trStatus': '2',
                'trStatusDesc': None,
                'trChangeDateTime': None,
                'authCode': '111111',
                'terminal': '11111111',
                'cardNumber': '220000******0000',
                'trID': '1000000000'
            }
        }
        """
        return self._client().service.getPaymentStatus(**args)

    def dailyReportRequest(self, **args):
        """
        >>> .dailyReportRequest(systemID='EXAMPLE', date='2017-08-07', status=2, signature='')
        {
            'operationResult': {
                'code': 3,
                'description': 'Неверная подпись.'
            },
            'orders': None
        }
        """
        return self._client().service.dailyReport(**args)




import re
import logging


class Base(object):
    FORMAT = '%(asctime)-15s %(clientip)s %(user)-8s %(message)s'

    def __init__(self, merchant_id, secret='', **args):
        self.merchant_id = merchant_id
        self.secret = secret

        logging.basicConfig(format=self.FORMAT)
        self.logger = logging.getLogger('a3')


    def validate_phone(self, phone):
        """Validate phone number

        See also: https://en.wikipedia.org/wiki/Telephone_numbers_in_Russia

        >>> Base().validate_phone('9100000000')
        True
        >>> Base().validate_phone('+79100000000')
        True
        >>> Base().validate_phone('89100000000')
        True

        :param phone: str
        :return: bool
        """
        pattern = r"^(\+?7|8)?(9\d{2})(\d{7})$"
        return True if re.compile(pattern).match(phone.replace(' ', '')) else False



from setuptools import setup

setup(
    name='A3SDK',
    version='0.0.1',
    author='Vyacheslav Anzhiganov',
    author_email='vanzhiganov@ya.ru',
    packages=[
        'A3SDK'
    ],
    install_requires=[
        'requests',
        'zeep',
    ]
)
